@@ -19,33 +19,33 @@ class Partner(PartnerBaseModel):
     """Model definition for Partner."""
 
     partner_slug = models.SlugField(
-        _("slug"),
+        _("Slug"),
         help_text=_("Slug of headquarter"),
         max_length=150,
     )
     name = models.CharField(
-        _("name"),
+        _("Name"),
         help_text=_("Name of partner"),
         max_length=150,
     )
     dni = models.CharField(
-        _("dni"),
+        _("Dni"),
         help_text=_("DNI of partner"),
         max_length=20,
     )
     email = models.EmailField(
-        _("email"),
+        _("Email"),
         help_text=_("Email of partner"),
         max_length=254,
     )
     city = models.ForeignKey(
         City,
-        verbose_name=_("city"),
+        verbose_name=_("City"),
         help_text=_("City of partner"),
         on_delete=models.CASCADE,
     )
     address = models.CharField(
-        _("address"),
+        _("Address"),
         help_text=_("Address of partner"),
         max_length=250,
     )
@@ -53,8 +53,8 @@ class Partner(PartnerBaseModel):
     class Meta:
         """Meta definition for Partner."""
 
-        verbose_name = "Partner"
-        verbose_name_plural = "Partners"
+        verbose_name = _("Partner")
+        verbose_name_plural = _("Partners")
 
     def __str__(self):
         """Unicode representation of Partner."""
@@ -65,18 +65,18 @@ class Headquarter(PartnerBaseModel):
     """Model definition for Headquarter."""
 
     name = models.CharField(
-        _("name"),
+        _("Name"),
         help_text=_("Name of headquarter"),
         max_length=150,
     )
     address = models.CharField(
-        _("address"),
+        _("Address"),
         help_text=_("Address of headquarter"),
         max_length=250,
     )
     city = models.ForeignKey(
         City,
-        verbose_name=_("city"),
+        verbose_name=_("City"),
         help_text=_("City of headquarter"),
         on_delete=models.CASCADE,
     )
@@ -95,8 +95,8 @@ class Headquarter(PartnerBaseModel):
     class Meta:
         """Meta definition for Headquarter."""
 
-        verbose_name = "Headquarter"
-        verbose_name_plural = "Headquarters"
+        verbose_name = _("Headquarter")
+        verbose_name_plural = _("Headquarters")
 
     def __str__(self):
         """Unicode representation of Headquarter."""
@@ -107,7 +107,7 @@ class Position(PartnerBaseModel):
     """Model definition for Position."""
 
     name = models.CharField(
-        _("name"),
+        _("Name"),
         help_text=_("Name of position"),
         max_length=150,
     )
@@ -115,8 +115,8 @@ class Position(PartnerBaseModel):
     class Meta:
         """Meta definition for Position."""
 
-        verbose_name = "Position"
-        verbose_name_plural = "Positions"
+        verbose_name = _("Position")
+        verbose_name_plural = _("Positions")
 
     def __str__(self):
         """Unicode representation of Position."""
@@ -127,17 +127,17 @@ class Coworker(PartnerBaseModel):
     """Model definition for Coworker."""
 
     first_name = models.CharField(
-        _("first_name"),
+        _("First name"),
         help_text=_("First name of coworker"),
         max_length=150,
     )
     last_name = models.CharField(
-        _("last_name"),
+        _("Last name"),
         help_text=_("Last name of coworker"),
         max_length=150,
     )
     dni = models.CharField(
-        _("dni"),
+        _("Dni"),
         help_text=_("DNI of coworker"),
         max_length=20,
     )
@@ -147,19 +147,19 @@ class Coworker(PartnerBaseModel):
         max_length=254,
     )
     phone = models.CharField(
-        _("phone"),
+        _("Phone"),
         help_text=_("Phone of coworker"),
         max_length=20,
     )
     headquarter = models.ForeignKey(
         Headquarter,
-        verbose_name=_("headquarter"),
+        verbose_name=_("Headquarter"),
         help_text=_("Headquarter of coworker"),
         on_delete=models.CASCADE,
     )
     position = models.ForeignKey(
         Position,
-        verbose_name=_("position"),
+        verbose_name=_("Position"),
         help_text=_("Position of coworker"),
         on_delete=models.CASCADE,
     )
@@ -167,8 +167,8 @@ class Coworker(PartnerBaseModel):
     class Meta:
         """Meta definition for Coworker."""
 
-        verbose_name = "Coworker"
-        verbose_name_plural = "Coworkers"
+        verbose_name = _("Coworker")
+        verbose_name_plural = _("Coworkers")
 
     def __str__(self):
         """Unicode representation of Coworker."""
